﻿using System;
using System.Windows.Forms;

namespace WindowsFormsApp1
{
    using MainTranslation = Properties.Resources;
    using ExtensionMethods;

    public partial class FrmApiConfig : Form
    {
        public string HotelId => TextBox_HotelId.Text;

        public string AppKey => TextBox_AppKey.Text;

        public string InterfaceId => TextBox_InterfaceId.Text;

        public string InterfaceKey => TextBox_InterfaceKey.Text;

        public string ClientId => TextBox_ClientId.Text;

        public string ClientKey => TextBox_ClientKey.Text;

        public string CsvOutputPath => TextBox_CsvOutputPath.Text;



        public FrmApiConfig() : this(null) { }

        public FrmApiConfig(ApiConfig config)
        {
            InitializeComponent();
            SetConfigValues(config);
        }


        private void FrmApiConfig_Load(object sender, EventArgs e) { }

        private void Button_Accept_Click(object sender, EventArgs e) => DialogResult = DialogResult.OK;

        private void Button_ToggleVisibility_Click(object sender, EventArgs e)
        {
            if (!(sender is Button btn))
                return;

            TextBox txtBox;
            if (btn == Button_ToggleAppKeyVisibility)
                txtBox = TextBox_AppKey;
            else if (btn == Button_ToggleClientKeyVisibility)
                txtBox = TextBox_ClientKey;
            else if (btn == Button_ToggleInterfaceKeyVisibility)
                txtBox = TextBox_InterfaceKey;
            else
                return;

            txtBox.UseSystemPasswordChar = !txtBox.UseSystemPasswordChar;
            btn.Text = TextBox_AppKey.UseSystemPasswordChar ? MainTranslation.Show : MainTranslation.Hide;
        }

        private void Button_SelectOutputPath_Click(object sender, EventArgs e)
        {
            using (SaveFileDialog sfd = new SaveFileDialog())
            {
                sfd.DefaultExt = "csv";
                sfd.FileName = "Oracle.csv";
                sfd.Filter = "CSV|*.csv";
                if (sfd.ShowDialog() == DialogResult.OK)
                    TextBox_CsvOutputPath.Text = sfd.FileName;
            }
        }

        private void Button_ImportConfig_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog ofd = new OpenFileDialog())
            {
                ofd.Filter = "XML|*.xml";
                if (ofd.ShowDialog() == DialogResult.OK)
                {
                    if (!ApiConfig.TryLoad(ofd.FileName, false, out ApiConfig cfg))
                    {
                        MessageBox.Show(MainTranslation.FailedToLoadConfiguration, MainTranslation.InvalidConfigurationFile, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                        return;
                    }
                    SetConfigValues(cfg);
                }
            }
        }

        private void SetConfigValues(ApiConfig config)
        {
            if (config == null)
                return;

            TextBox_AppKey.Text = config.AccessToken?.ToPlainText();
            TextBox_HotelId.Text = config.HotelId;
            TextBox_InterfaceId.Text = config.InterfaceId;
            TextBox_InterfaceKey.Text = config.InterfaceKey?.ToPlainText();
            TextBox_ClientId.Text = config.ClientId;
            TextBox_ClientKey.Text = config.ClientKey?.ToPlainText();
            TextBox_CsvOutputPath.Text = config.CsvFilePath;
        }
    }
}
